codec-corpus
Runtime API for downloading, caching, and accessing test image datasets
from the imazen/codec-corpus
GitHub repository.
No data ships with the crate. Datasets are fetched lazily on first access and cached locally.
let corpus = codec_corpus::Corpus::new().unwrap();
let valid = corpus.get("webp-conformance/valid").unwrap();
for entry in std::fs::read_dir(valid).unwrap() {
let path = entry.unwrap().path();
println!("{}", path.display());
}Structs
- Corpus
- Handle for accessing cached test-image datasets.
Enums
- Error
- Errors that can occur when using the corpus.